import ProxiedUrl from '../../src/lib/proxied-url';

describe('Url Proxy', () => {
  const baseUrl: string = 'https://www.organicfacts.net';

  test('proxies full URLs', () => {
	const resourceUrl: string = 'https://www.organicfacts.net/wp-content/uploads/2013/06/Pineapple.jpg';

	const proxiedUrl: string = new ProxiedUrl(baseUrl, resourceUrl).url();

	expect(proxiedUrl).toBe('https://assets.hellomedian.com/asset/68747470733a2f2f7777772e6f7267616e696366616374732e6e65742f77702d636f6e74656e742f75706c6f6164732f323031332f30362f50696e656170706c652e6a7067');
  });

  test('proxies relative URLs', () => {
	const resourceUrl: string = '/wp-content/uploads/2013/06/Pineapple.jpg';

	const proxiedUrl: string = new ProxiedUrl(baseUrl, resourceUrl).url();

	expect(proxiedUrl).toBe('https://assets.hellomedian.com/asset/68747470733a2f2f7777772e6f7267616e696366616374732e6e65742f77702d636f6e74656e742f75706c6f6164732f323031332f30362f50696e656170706c652e6a7067');
  });

  test('only replaces URLs on blobbed links', () => {
	const resourceUrl: string = 'blob:https://www.organicfacts.net/wp-content/uploads/2013/06/Pineapple.jpg';

	const proxiedUrl: string = new ProxiedUrl(baseUrl, resourceUrl).url();

	expect(proxiedUrl).toBe('blob:https://assets.hellomedian.com/asset/68747470733a2f2f7777772e6f7267616e696366616374732e6e65742f77702d636f6e74656e742f75706c6f6164732f323031332f30362f50696e656170706c652e6a7067');
  });

  test('does not proxy inlined data', () => {
	const resourceUrl: string = 'data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIy NCIgaGVpZ2h0PSIyNCIgdmlld0JveD0iMCAwIDI0IDI0Ij4KICAgIDxwYXRoIGQ9 Ik0wIDBoMjR2MjRoLTI0eiIgZmlsbD0ibm9uZSIvPgogICAgPHBhdGggZD0iTTEw LjA5IDE1LjU5bDEuNDEgMS40MSA1LTUtNS01LTEuNDEgMS40MSAyLjU4IDIuNTlo LTkuNjd2Mmg5LjY3bC0yLjU4IDIuNTl6bTguOTEtMTIuNTloLTE0Yy0xLjExIDAt MiAuOS0yIDJ2NGgydi00aDE0djE0aC0xNHYtNGgtMnY0YzAgMS4xLjg5IDIgMiAy aDE0YzEuMSAwIDItLjkgMi0ydi0xNGMwLTEuMS0uOS0yLTItMnoiLz4KPC9zdmc+ Cg==';

	const proxiedUrl: string = new ProxiedUrl(baseUrl, resourceUrl).url();

	expect(proxiedUrl).toBe(resourceUrl);
  });

  test('Corrects protocol paths of blobs', () => {
	const resourceUrl: string = 'blob:https//sendgrid.com/56ed799d-f9db-4d66-89a3-8994d2c1f5f8';

	const proxiedUrl: string = new ProxiedUrl(baseUrl, resourceUrl).url();

	expect(proxiedUrl).toBe('blob:https://assets.hellomedian.com/asset/68747470733a2f2f73656e64677269642e636f6d2f35366564373939642d663964622d346436362d383961332d383939346432633166356638');
  });

  test('Returns a blank string the url matches a blacklisted regex', () => {
	const resourceUrl: string = 'https://sumo.com/apps/contentanalytics/scroll?site_id=b1e5a97fc1f4381bb3857489e910c430b3cac846d2ed712cbb29e8b3090a125d&last=&read=0&path=%2F&_=0.08830501172502903';

	const proxiedUrl: string = new ProxiedUrl(baseUrl, resourceUrl).url();

	expect(proxiedUrl).toBe('');
  });
})